※下の方に日本語の説明があります

## English description
This package provides a simple output of python objects.

How to use

```python
from sout import sout

large_obj = [[1,2,3] for _ in range(9999)]
sout(large_obj)
```

output
```
[
  [ 1, 2, 3, ],
  [ 1, 2, 3, ],
  [ 1, 2, 3, ],
  [ 1, 2, 3, ],
  [ 1, 2, 3, ],
  ... (all_n = 9999)
]
```

## 日本語の説明
オブジェクトをわかりやすく表示するためのパッケージです

簡単な使い方
```python
from sout import sout

large_obj = [[1,2,3] for _ in range(9999)]
sout(large_obj)
```

出力結果
```
[
  [ 1, 2, 3, ],
  [ 1, 2, 3, ],
  [ 1, 2, 3, ],
  [ 1, 2, 3, ],
  [ 1, 2, 3, ],
  ... (all_n = 9999)
]
```
